package com.softslate.commerce.administrator.core;

import java.io.File;
import java.io.FileOutputStream;
import java.util.Map;
import java.util.Properties;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.beanutils.PropertyUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

import com.softslate.commerce.businessobjects.core.Settings;
import com.softslate.commerce.customer.core.ActionUtils;
import com.softslate.commerce.customer.core.BaseAction;
import com.softslate.commerce.customer.core.BaseDynaForm;
import com.softslate.commerce.daos.core.DAOFactory;

/**
 * @author David Tobey
 * 
 */
public class SettingsAction extends BaseAction {

	static Log log = LogFactory.getLog(SettingsAction.class);

	public ActionForward execute(ActionMapping mapping, ActionForm form,
			HttpServletRequest request, HttpServletResponse response)
			throws Exception {
		if (log.isDebugEnabled())
			log.debug("Starting action.");
		BaseDynaForm baseForm = (BaseDynaForm) form;
		ActionUtils actionUtils = (ActionUtils) baseForm
				.getBusinessObjectFactory().createUtilsObject(
						"actionUtilsImplementer");
		Map properties = actionUtils.buildParameterMap(request);
		properties.putAll(PropertyUtils.describe(baseForm));
		Settings settingsBean =  baseForm.getBusinessObjectFactory()
				.createObject(Settings.class);
		synchronized (getServlet().getServletContext()) {
			Settings settings = settingsBean.processSettings(properties);
			servlet.getServletContext().setAttribute("settingsBean", settings);
			servlet.getServletContext().setAttribute("settings", settings);
			baseForm.getBusinessObjectFactory().setSettings(settings);
			request.setAttribute("settings", settings);
			// Place the new Settings in the application scope.
			DAOFactory daoFactory = (DAOFactory) getServlet()
					.getServletContext().getAttribute("daoFactory");
			daoFactory.setSettings(settings);
		}
		baseForm.getMessages().add(ActionMessages.GLOBAL_MESSAGE,
				new ActionMessage("messages.settingsMessage"));
		if (!baseForm.getMessages().isEmpty())
			saveMessages(request, baseForm.getMessages());
		if (log.isDebugEnabled())
			log.debug("Finished with Action.");
		return mapping.findForward("success");
	}

	/**
	 * Saves a new set of properties to the /WEB-INF/classes/appComponents.properties file.
	 * 
	 * @param appComponents
	 *            The new set of properties to be saved.
	 * @throws Exception
	 *             If there is an issue reading or writing to the file.
	 * 
	 */
	public void saveComponents(Properties appComponents) throws Exception {

		// Check if saving components from the admin is disabled in appSettings.properties
		Properties appSettings = (Properties) getServlet().getServletContext().getAttribute("appSettings");
		if (appSettings == null || appSettings.getProperty("disableComponentUpdatesFromAdministrator") == null
				|| appSettings.getProperty("disableComponentUpdatesFromAdministrator").equals("0")) {
			String appComponentsPath = getServlet()
					.getServletContext()
					.getRealPath("/WEB-INF/classes/appComponents-custom.properties");
			File appComponentsFile = new File(appComponentsPath);
			FileOutputStream fos = new FileOutputStream(appComponentsFile);
			if (log.isDebugEnabled())
				log.debug(
						"Attempting to write components to " + appComponentsFile + " appComponents: " + appComponents);
			appComponents.store(fos, "Generated by Administrator.");

			// In case we're in an environment with an src folder, save
			// the file to the src area too.
			String appComponentsPathSrc = null;
			try {
				appComponentsPathSrc = getServlet().getServletContext()
						.getRealPath("/WEB-INF/src/appComponents-custom.properties");
				File appComponentsFileSrc = new File(appComponentsPathSrc);
				FileOutputStream fosSrc = new FileOutputStream(appComponentsFileSrc);
				if (log.isDebugEnabled())
					log.debug("Attempting to write components to " + appComponentsFileSrc + " appComponents: "
							+ appComponents);
				appComponents.store(fosSrc, "Generated by Administrator.");
			} catch (Exception e) {
				if (log.isInfoEnabled())
					log.info("Error attempting to write components to " + appComponentsPathSrc, e);
			}
		} else {
			log.info("Saving components is disabled by the disableComponentUpdatesFromAdministrator setting.");
		}
	}
}
