package com.softslate.commerce.administrator.core;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.beanutils.PropertyUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

import com.softslate.commerce.businessobjects.administrator.UpgradesProcessor;
import com.softslate.commerce.businessobjects.core.Settings;
import com.softslate.commerce.daos.core.DAOFactory;

/**
 * @author David Tobey
 */
public class UpgradesProcessAction extends UpgradesAction {

    static Log log = LogFactory.getLog(UpgradesProcessAction.class);

    public ActionForward execute(ActionMapping mapping, ActionForm form,
            HttpServletRequest request, HttpServletResponse response)
            throws Exception {
        if (log.isDebugEnabled())
            log.debug("Starting action.");
        UpgradesForm baseForm = (UpgradesForm) form;
        Map properties = PropertyUtils.describe(form);

        // Set the current version of the database objects.
        String currentVersion = (String) baseForm.getSettings().getValue(
                "dataObjectsVersion");
        if (currentVersion == null) {
            currentVersion = "1.0.3";
        }

        // Set the database type - mssql or mysql.
        String dbType = baseForm.getBusinessObjectFactory().getDaoFactory()
                .getDatabaseType().toLowerCase();

        // Set the path to the upgrades directory.
        String pathToUpgrades = getServlet().getServletContext().getRealPath(
                "/WEB-INF/classes/resources/upgrades/");

        // Collect the upgrades into a sorted ArrayList
        UpgradesAction upgradesAction = new UpgradesAction();
        ArrayList upgrades = upgradesAction.collectUpgrades(currentVersion,
                pathToUpgrades, dbType);

        // Only do the upgrades that were checked off.
        ArrayList upgradesToDo = new ArrayList();
        String[] selectedUpgrades = (String[]) baseForm.get("upgrades");
        Iterator i = upgrades.iterator();
        while (i.hasNext()) {
            Map upgrade = (Map) i.next();
            String upgradeFromVersion = (String) upgrade
                    .get("upgradeFromVersion");
            String upgradeToVersion = (String) upgrade.get("upgradeToVersion");
            String databaseType = (String) upgrade.get("databaseType");
            for (int j = 0; j < selectedUpgrades.length; j++) {
                if (selectedUpgrades[j].equals(upgradeFromVersion + "_"
                        + upgradeToVersion + "_" + databaseType)) {
                    upgradesToDo.add(upgrade);
                }
            }
        }
        if (log.isDebugEnabled())
            log.debug("upgradesToDo: " + upgradesToDo);

        // Process the upgrades
        properties.put("currentVersion", currentVersion);
        properties.put("pathToUpgrades", pathToUpgrades);
        properties.put("upgrades", upgradesToDo);
        UpgradesProcessor upgradesProcessor = (UpgradesProcessor) baseForm
                .getBusinessObjectFactory()
                .createObjectFromClassName(
                        "com.softslate.commerce.businessobjects.administrator.UpgradesProcessor");
        Settings settings = upgradesProcessor.processUpgrades(properties);

        // Place the new Settings in the application scope.
        DAOFactory daoFactory = (DAOFactory) getServlet().getServletContext()
                .getAttribute("daoFactory");
        settings.initialize();
        synchronized (getServlet().getServletContext()) {
            servlet.getServletContext().setAttribute("settingsBean", settings);
            servlet.getServletContext().setAttribute("settings", settings);
            daoFactory.setSettings(settings);
        }
        baseForm.getBusinessObjectFactory().setSettings(settings);
        request.setAttribute("settings", settings);

        // Save a success message to the request.
        ActionMessages messages = new ActionMessages();
        messages.add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage(
                "messages.upgradeSuccess"));
        if (!messages.isEmpty())
            saveMessages(request, messages);
        if (log.isDebugEnabled())
            log.debug("Finished with Action.");
        return mapping.findForward("success");
    }
}
