package com.softslate.commerce.administrator.customer;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.beanutils.PropertyUtils;
import org.apache.commons.lang3.StringEscapeUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

import com.softslate.commerce.administrator.core.BaseAdministratorForm;
import com.softslate.commerce.businessobjects.customer.Customer;
import com.softslate.commerce.businessobjects.customer.CustomerProcessor;
import com.softslate.commerce.customer.core.BaseAction;

/**
 * Struts action class that corresponds to requests to "/administrator/CustomerAdd.do". Processes a request to add a
 * record to the system.
 * 
 * @author David Tobey
 * 
 */
public class CustomerAddAction extends BaseAction {

	static Log log = LogFactory.getLog(CustomerAddAction.class);

	public ActionForward execute(ActionMapping mapping, ActionForm form, HttpServletRequest request,
			HttpServletResponse response) throws Exception {
		if (log.isDebugEnabled())
			log.debug("Starting action.");

		// Add the record
		BaseAdministratorForm baseForm = (BaseAdministratorForm) form;

		CustomerProcessor processor = (CustomerProcessor) baseForm.getBusinessObjectFactory()
				.createObject("customerProcessorImplementer");
		Map results = processor.addCustomer(PropertyUtils.describe(form));

		// Set the success messages
		if (results != null && results.get("newRecord") != null) {
			Customer newRecord = (Customer) results.get("newRecord");

			// entity.jsp wants the new record in the request scope.
			request.setAttribute("customer", newRecord);

			// Set success message
			baseForm.getMessages().add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage("messages.recordAdded"));
			baseForm.getMessages().add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage("messages.editNewRecord",
					"CustomerEditForm.do?customerID=" + newRecord.getCustomerID()));
			request.setAttribute("okNotToEscapeMessages", Boolean.TRUE);

			// If successful, signal the form to be reinstantiated.
			request.setAttribute("reset", "true");
		} else if (results != null && results.get("existingRecord") != null) {

			// Set the error messages
			Customer existingRecord = (Customer) results.get("existingRecord");
			String existingUserName = StringEscapeUtils.escapeXml11(existingRecord.getUserName());
			request.setAttribute("okNotToEscapeMessages", Boolean.TRUE);
			baseForm.getErrors().add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage(
					"errors.resultCode" + results.get("resultCode"), results.get("duplicateField"), existingUserName));
			baseForm.getErrors().add(ActionMessages.GLOBAL_MESSAGE,
					new ActionMessage("errors.editExistingRecord",
							"CustomerEditForm.do?customerID=" + existingRecord.getCustomerID(),
							results.get("duplicateField"), existingUserName));
		}
		saveMessages(baseForm.getRequest(), baseForm.getMessages());
		saveErrors(baseForm.getRequest(), (ActionMessages) baseForm.getErrors());
		return mapping.findForward("success");
	}
}
