package com.softslate.commerce.administrator.email;

import java.util.Arrays;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.beanutils.PropertyUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

import com.softslate.commerce.businessobjects.core.BusinessObjectFactory;
import com.softslate.commerce.businessobjects.customer.Customer;
import com.softslate.commerce.businessobjects.customer.CustomerProcessor;
import com.softslate.commerce.businessobjects.email.EmailProcessor;
import com.softslate.commerce.businessobjects.email.Template;
import com.softslate.commerce.businessobjects.email.TemplateProcessor;
import com.softslate.commerce.businessobjects.order.Order;
import com.softslate.commerce.businessobjects.order.OrderProcessor;
import com.softslate.commerce.customer.core.BaseAction;

/**
 * Struts action class that corresponds to the main administrator view panel for
 * Emails. Used for requests to "/administrator/Email.do".
 * <p>
 * The <code>execute</code> method of this class populates a
 * <code>Collection</code> named <code>itemCollection</code> in the request
 * scope containing the items to be displayed. Next, it sets a request scope
 * variable named <code>editPermission</code> that determines if the current
 * user has permission to edit the items. Finally, it creates a
 * <code>Collection</code> named <code>breadcrumbs</code> containing the
 * links and labels of each breadcrumb for display.
 * 
 * 
 */
public class EmailAction extends BaseAction {

	static Log log = LogFactory.getLog(EmailAction.class);

	public ActionForward execute(ActionMapping mapping, ActionForm form, HttpServletRequest request, HttpServletResponse response) throws Exception {
		if (log.isDebugEnabled()) log.debug("Starting action.");

		// Handle the main form for the control screen
		EmailForm baseForm = (EmailForm) form;
		baseForm.setProperties(request);
		request.setAttribute("mainForm", baseForm);

		// Handle the quick-add form
		EmailAddEditForm addForm = (EmailAddEditForm) request.getAttribute("emailAddEditForm");
		if (addForm == null || (request.getAttribute("reset") != null && request.getAttribute("reset").equals("true"))) {
			addForm = new EmailAddEditForm();
			if (baseForm.getParentOrderID() != null && !baseForm.getParentOrderID().equals("")) {
				addForm.setOrderID(new Integer(baseForm.getParentOrderID()));
			}
			if (baseForm.getParentCustomerID() != null && !baseForm.getParentCustomerID().equals("")) {
				addForm.setCustomerID(new Integer(baseForm.getParentCustomerID()));
			}
			if (baseForm.getParentTemplateID() != null && !baseForm.getParentTemplateID().equals("")) {
				addForm.setTemplateID(new Integer(baseForm.getParentTemplateID()));
			}
		}
		addForm.initializeProperties(mapping, request);
		request.setAttribute("emailAddEditForm", addForm);

		// Get the collection of items to display
		BusinessObjectFactory bof = (BusinessObjectFactory) request.getAttribute("businessObjectFactory");
		EmailProcessor processor =  bof.createObject(EmailProcessor.class);
		Map emailsAndCount = processor.loadEmailsAndCount(PropertyUtils.describe(baseForm));
		request.setAttribute("emails", emailsAndCount.get("items"));
		request.setAttribute("itemCollection", emailsAndCount.get("items"));
		request.setAttribute("itemCount", emailsAndCount.get("itemCount"));
		
		// Load orders for the order drop down.
		OrderProcessor orderProcessor =  bof.createObject(OrderProcessor.class);
		// Collection orders = orderProcessor.loadAllOrders();
		// request.setAttribute("orders", orders);
		
		// Load customers for the customer drop down.
		CustomerProcessor customerProcessor =  bof.createObject(CustomerProcessor.class);
		// Collection customers = customerProcessor.loadAllCustomers();
		// request.setAttribute("customers", customers);
		
		// Load customers for the customer drop down.
		TemplateProcessor templateProcessor =  bof.createObject(TemplateProcessor.class);
		// Collection customers = customerProcessor.loadAllCustomers();
		// request.setAttribute("customers", customers);

		// Enforce role permissions
		if (!request.isUserInRole("superuser") && !request.isUserInRole("administrator") && !request.isUserInRole("emailEdit")) {
			request.setAttribute("editPermission", "false");
			baseForm.setEditMode("false");
		} else {
			request.setAttribute("editPermission", "true");
		}

		// Create breadcrumbing collection
		Collection bcs = Arrays.asList(new String[] { "Home", "Emails" });
		request.setAttribute("breadcrumbs", bcs);

		// Load the parent if an id is present
		Order order = null;
		if (baseForm.getParentOrderID() != null && baseForm.getParentOrderID().length() > 0) {
			Map parameters = new HashMap();
			parameters.put("orderID", baseForm.getParentOrderID());
			order = orderProcessor.loadOrderFromID(parameters);
			request.setAttribute("order", order);

			// Create breadcrumbing collection
			bcs = Arrays.asList(new String[] { "Home", "Orders", "Order Details", "Emails" });
			request.setAttribute("breadcrumbs", bcs);
		}
		
		// Load the parent if an id is present
		Customer customer = null;
		if (baseForm.getParentCustomerID() != null && baseForm.getParentCustomerID().length() > 0) {
			Map parameters = new HashMap();
			parameters.put("customerID", baseForm.getParentCustomerID());
			customer = customerProcessor.loadCustomerFromID(parameters);
			request.setAttribute("customer", customer);

			// Create breadcrumbing collection
			bcs = Arrays.asList(new String[] { "Home", "Customers", "Customer Details", "Emails" });
			request.setAttribute("breadcrumbs", bcs);
		}
		
		// Load the parent if an id is present
		Template template = null;
		if (baseForm.getParentTemplateID() != null && baseForm.getParentTemplateID().length() > 0) {
			Map parameters = new HashMap();
			parameters.put("templateID", baseForm.getParentTemplateID());
			template = templateProcessor.loadTemplateFromID(parameters);
			request.setAttribute("template", template);

			// Create breadcrumbing collection
			bcs = Arrays.asList(new String[] { "Home", "Templates", "Template Details", "Emails" });
			request.setAttribute("breadcrumbs", bcs);
		}

				// Forward according to the outputMode of the request
		if (baseForm.getOutputMode().equals("print")) {
			request.setAttribute("outputMode", "print");
			baseForm.setOutputMode("screen");
			return mapping.findForward("successSimpleLayout");
		} else if (baseForm.getOutputMode().equals("excel")) {
			request.setAttribute("outputMode", "excel");
			baseForm.setOutputMode("screen");
			response.setHeader("Content-Type", "application/vnd.ms-excel");
			response.setHeader("Content-Disposition",
					"attachment; filename=emails.xls");
			return mapping.findForward("successSimpleLayout");
		}
		return mapping.findForward("success");
	}
}
