package com.softslate.commerce.administrator.importexport;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

import com.softslate.commerce.businessobjects.core.BusinessObjectFactory;
import com.softslate.commerce.businessobjects.core.Settings;
import com.softslate.commerce.businessobjects.importexport.QboConnectionProcessor;
import com.softslate.commerce.customer.core.BaseAction;
import com.softslate.commerce.customer.core.BaseForm;
import com.softslate.commerce.daos.core.DAOFactory;

public class QboOauth2CallbackAction extends BaseAction {

	static Log log = LogFactory.getLog(QboOauth2CallbackAction.class);

	public ActionForward execute(ActionMapping mapping, ActionForm form, HttpServletRequest request,
			HttpServletResponse response) throws Exception {
		log.debug("Starting action.");
		BaseForm baseForm = new BaseForm();
		baseForm.initializeProperties(mapping, request);
		BusinessObjectFactory bof = baseForm.getBusinessObjectFactory();
		QboConnectionProcessor qboProcessor = bof.createObject(QboConnectionProcessor.class);
		Map<String, Object> results = qboProcessor.oauth2Callback(request.getParameter("code"),
				request.getParameter("state"),
				request.getParameter("realmId"), (String) request.getSession().getAttribute("csrfToken"));
		if (results.get("error") != null) {
			saveErrorFromQboResult(baseForm, results);
			return mapping.findForward("failure");
		}

		// Store the tokens as global settings - they belong to the application itself.
		Settings settingsBean = bof.createObject(Settings.class);
		synchronized (getServlet().getServletContext()) {
			Settings settings = settingsBean.processSettings(results);
			servlet.getServletContext().setAttribute("settingsBean", settings);
			servlet.getServletContext().setAttribute("settings", settings);
			bof.setSettings(settings);
			request.setAttribute("settings", settings);
			DAOFactory daoFactory = (DAOFactory) getServlet().getServletContext().getAttribute("daoFactory");
			daoFactory.setSettings(settings);
		}

		log.info("tokens: " + results);
		return mapping.findForward("success");
	}

	private void saveErrorFromQboResult(BaseForm baseForm, Map results) {
		Map error = (Map) results.get("error");
		String resultCode = (String) error.get("resultCode");
		String resultMessage = (String) error.get("resultMessage");
		if (resultCode == null || !resultCode.equals("0")) {
			String message = baseForm.getMessage("importexport", "qbo.processingError" + resultCode, null);
			if (message == null || message.length() == 0) {
				if (resultMessage == null) {
					message = baseForm.getMessage("importexport", "qbo.processingError", null);
				} else {
					message = baseForm.getMessage("importexport", "qbo.processingErrorArg",
							new String[] { resultMessage });
				}
			}
			baseForm.getErrors().add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage("errors.detail", message));
			saveErrors(baseForm.getRequest(), (ActionMessages) baseForm.getErrors());
			if (log.isInfoEnabled() && !baseForm.getErrors().isEmpty())
				log.info("Validation error(s): " + baseForm.getErrors().toString());
		}
	}

}
