package com.softslate.commerce.administrator.importexport;

import java.text.SimpleDateFormat;
import java.util.Locale;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

import com.softslate.commerce.administrator.core.BaseAdministratorForm;

/**
 * Struts ActionForm class responsible for the Sales By Product report form.
 * Provides properties for defining the report's date range and output format.
 * 
 * @author David Tobey
 * 
 */
public class SalesByProductForm extends BaseAdministratorForm {

	private static final long serialVersionUID = 1L;

	static Log log = LogFactory.getLog(SalesByProductForm.class);

	private String startDate = "2000-01-01";

	private String endDate = (new SimpleDateFormat("yyyy-MM-dd", Locale
			.getDefault()).format(new java.util.Date()));

	private String headerRow = "true";

	private String outputFormat = "screen";

	private Integer[] productIDs = null;

	private Integer[] selectedID = null;

	public String getStartDate() {
		return startDate;
	}

	public void setStartDate(String startDate) {
		this.startDate = startDate;
	}

	public String getEndDate() {
		return endDate;
	}

	public void setEndDate(String endDate) {
		this.endDate = endDate;
	}

	public String getHeaderRow() {
		return headerRow;
	}

	public void setHeaderRow(String headerRow) {
		this.headerRow = headerRow;
	}

	public String getOutputFormat() {
		return outputFormat;
	}

	public void setOutputFormat(String outputFormat) {
		this.outputFormat = outputFormat;
	}

	public Integer[] getProductIDs() {
		return productIDs;
	}

	public void setProductIDs(Integer[] productIDs) {
		this.productIDs = productIDs;
	}

	public Integer[] getSelectedID() {
		return selectedID;
	}

	public void setSelectedID(Integer[] selectedID) {
		this.selectedID = selectedID;
	}

	public ActionErrors validate(ActionMapping mapping,
			HttpServletRequest request) {
		if (log.isDebugEnabled())
			log.debug("Starting validation.");
		initializeProperties(mapping, request);

		// Set how many records to process at once
		int maxRecordsProcessed = 1000;
		try {
			maxRecordsProcessed = Integer.parseInt((String) getSettings()
					.getValue("maxRecordsProcessed"));
		} catch (Exception e) {
			log.warn("No maxRecordsProcessed, defaulting to 1000: ", e);
		}

		// Check for dates
		if (getStartDate() == null || getStartDate().equals("")) {
			getErrors().add(ActionMessages.GLOBAL_MESSAGE,
					new ActionMessage("errors.required", "Start Date"));
		}
		if (getEndDate() == null || getEndDate().equals("")) {
			getErrors().add(ActionMessages.GLOBAL_MESSAGE,
					new ActionMessage("errors.required", "End Date"));
		}

		// Check for the number of products being reported on
		if (getProductIDs() == null || getProductIDs().length == 0
				|| getProductIDs()[0].equals("")) {
			getErrors()
					.add(
							ActionMessages.GLOBAL_MESSAGE,
							new ActionMessage("errors.required",
									"At least one product"));
		} else if (getProductIDs().length > maxRecordsProcessed) {
			getErrors().add(
					ActionMessages.GLOBAL_MESSAGE,
					new ActionMessage("errors.tooManyProductsInReport", Integer
							.toString(maxRecordsProcessed)));
			request.setAttribute("displayProducts", "true");
		}
		return getErrors();
	}
}
