package com.softslate.commerce.administrator.order;

import java.util.Arrays;
import java.util.Collection;
import java.util.Locale;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.beanutils.PropertyUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

import com.softslate.commerce.businessobjects.core.User;
import com.softslate.commerce.businessobjects.order.CartProcessor;
import com.softslate.commerce.businessobjects.order.Order;
import com.softslate.commerce.businessobjects.order.OrderProcessor;
import com.softslate.commerce.customer.core.BaseAction;

/**
 * Struts action class corresponding to requests to
 * "/administrator/SendEmails.do". Loads in the current order being worked with
 * so that the JSPs can send out the appropriate emails.
 * 
 * @author David Tobey
 * 
 */
public class SendEmailsAction extends BaseAction {

	static Log log = LogFactory.getLog(SendEmailsAction.class);

	public ActionForward execute(ActionMapping mapping, ActionForm form,
			HttpServletRequest request, HttpServletResponse response)
			throws Exception {
		if (log.isDebugEnabled())
			log.debug("Starting action.");
		SendEmailsForm baseForm = (SendEmailsForm) form;

		// Get the order record
		OrderProcessor processor = baseForm.getBusinessObjectFactory().createObject(OrderProcessor.class);
		Order order = processor.loadOrderFromID(PropertyUtils.describe(form));

		// Send the order confirmation and notification emails using a Template, if called for by the settings.
		// Otherwise, the legacy orderEmails.jsp will send them.
		if (!"1".equals(baseForm.getSettings().getValue("useLegacyJSPOrderEmailTemplates"))) {
			CartProcessor cartProcessor = baseForm.getBusinessObjectFactory().createObject(CartProcessor.class);
			cartProcessor.sendOrderCompleteEmails(order, PropertyUtils.describe(baseForm));
		} else {

			// Prepare to send out the notification emails
			// Put a user bean in the request scope for the JSPs
			User newUser = (User) baseForm.getBusinessObjectFactory().createObject("userImplementer");
			newUser.setOrder(order);
			newUser.setLocale(Locale.getDefault());
			baseForm.getRequest().setAttribute("user", newUser);

			// Place the baseForm in the request - used by the orderEmails.jsp file
			baseForm.getRequest().setAttribute("baseForm", baseForm);
		}

		// Set the message saying the emails are being sent
		if (baseForm.getSendCustomerEmail() != null
				&& baseForm.getSendCustomerEmail().equals("true")) {
			baseForm.getMessages().add(ActionMessages.GLOBAL_MESSAGE,
					new ActionMessage("messages.sendingCustomerEmail"));
			saveMessages(baseForm.getRequest(), baseForm.getMessages());
		}
		if (baseForm.getSendNotificationEmail() != null
				&& baseForm.getSendNotificationEmail().equals("true")) {
			baseForm.getMessages().add(ActionMessages.GLOBAL_MESSAGE,
					new ActionMessage("messages.sendingNotificationEmail"));
			saveMessages(baseForm.getRequest(), baseForm.getMessages());
		}
		if (baseForm.getSendGiftCertificateEmails() != null
				&& baseForm.getSendGiftCertificateEmails().equals("true")) {
			baseForm.getMessages().add(ActionMessages.GLOBAL_MESSAGE,
					new ActionMessage("messages.sendingGiftCertificateEmails"));
			saveMessages(baseForm.getRequest(), baseForm.getMessages());
		}

		// Enforce role permissions
		if (!request.isUserInRole("superuser")
				&& !request.isUserInRole("administrator")
				&& !request.isUserInRole("orderEdit")) {
			request.setAttribute("editPermission", "false");
		} else {
			request.setAttribute("editPermission", "true");
		}

		// Create breadcrumbing collection
		Collection bcs = Arrays.asList(new String[] { "Home", "Orders",
				"Order Details", "Send Order Emails" });
		request.setAttribute("breadcrumbs", bcs);

		request.setAttribute("orderAddEditForm", order);
		request.setAttribute("order", order);

		return mapping.findForward("success");
	}
}
