package com.softslate.commerce.administrator.product;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.beanutils.PropertyUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

import com.softslate.commerce.businessobjects.core.BusinessObjectFactory;
import com.softslate.commerce.businessobjects.product.ProductProcessor;
import com.softslate.commerce.customer.core.BaseAction;

/**
 * Struts action class that corresponds to requests to "/administrator/ProductAssign.do". Processes a request to assign
 * a Product to a parent.
 * 
 * @author David Tobey
 */
public class ProductAssignAction extends BaseAction {

	static Log log = LogFactory.getLog(ProductAssignAction.class);

	public ActionForward execute(ActionMapping mapping, ActionForm form, HttpServletRequest request,
			HttpServletResponse response) throws Exception {
		if (log.isDebugEnabled())
			log.debug("Starting action.");
		ProductForm baseForm = (ProductForm) form;

		// Validate here because we only need to check a couple of things and ProductForm.validate is used by
		// ProductEditDeleteAction
		ActionErrors errors = new ActionErrors();
		if ((baseForm.getCode() == null || baseForm.getCode()[0].equals(""))
				&& (baseForm.getProductID() == null || baseForm.getProductID()[0].equals(""))) {
			errors.add(ActionMessages.GLOBAL_MESSAGE,
					new ActionMessage("errors.required", "Product code or Product ID"));
		}
		if ((baseForm.getCategoryID() == null || baseForm.getCategoryID().equals(""))
				&& (baseForm.getAttributeID() == null || baseForm.getAttributeID().equals(""))
				&& (baseForm.getParentProductID() == null || baseForm.getParentProductID().equals(""))
				&& (baseForm.getParentManufacturerID() == null || baseForm.getParentManufacturerID().equals(""))
				&& (baseForm.getCustomerWishListID() == null || baseForm.getCustomerWishListID().equals(""))) {
			errors.add(ActionMessages.GLOBAL_MESSAGE,
					new ActionMessage("errors.required", "ID of the parent is required"));
		}
		if (!errors.isEmpty()) {
			saveErrors(request, errors);
			return mapping.findForward("success");
		}

		// Prepare parameters for the edit/delete processing, and process
		baseForm.setProperties(request);
		BusinessObjectFactory bof = (BusinessObjectFactory) request.getAttribute("businessObjectFactory");
		ProductProcessor processor = bof.createObject(ProductProcessor.class);
		Map parameters = PropertyUtils.describe(form);
		Map results = processor.editProductAssignment(parameters);
		if (results != null && results.get("resultCode") != null && results.get("resultCode").equals("NotFound")) {
			errors.add(ActionMessages.GLOBAL_MESSAGE,
					new ActionMessage("errors.detail", "Record not found"));
			saveErrors(request, errors);
		} else {

			// Set the success message
			ActionMessages messages = new ActionMessages();
			messages.add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage("messages.recordsSaved"));
			saveMessages(request, messages);
		}

		return mapping.findForward("success");
	}
}
