package com.softslate.commerce.administrator.tax;

import java.util.Arrays;
import java.util.Collection;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.beanutils.BeanUtils;
import org.apache.commons.beanutils.PropertyUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

import com.softslate.commerce.businessobjects.tax.BasicTaxRate;
import com.softslate.commerce.businessobjects.tax.TaxRateProcessor;
import com.softslate.commerce.customer.core.BaseAction;

/**
 * Struts action class corresponding to requests to
 * "/administrator/BasicTaxEditForm.do". Loads in the current values of the
 * record being edited and populates a <code>BasicTaxAddEditForm</code>
 * object.
 * 
 * @author David Tobey
 */
public class BasicTaxEditFormAction extends BaseAction {

	static Log log = LogFactory.getLog(BasicTaxAddFormAction.class);

	public ActionForward execute(ActionMapping mapping, ActionForm form,
			HttpServletRequest request, HttpServletResponse response)
			throws Exception {
		if (log.isDebugEnabled())
			log.debug("Starting action.");
		BasicTaxAddEditForm baseForm = (BasicTaxAddEditForm) form;
		baseForm.initializeProperties(mapping, request);

		// Get the record to edit
		TaxRateProcessor processor = (TaxRateProcessor) baseForm
				.getBusinessObjectFactory().createObject(
						"taxRateProcessorImplementer");
		BasicTaxRate basicTaxRate = processor
				.loadBasicTaxRateFromID(PropertyUtils.describe(form));
		BeanUtils.copyProperties(baseForm, basicTaxRate);

		// Enforce role permissions
		if (!request.isUserInRole("superuser")
				&& !request.isUserInRole("administrator")
				&& !request.isUserInRole("taxEdit")) {
			request.setAttribute("editPermission", "false");
		} else {
			request.setAttribute("editPermission", "true");
		}

		// Create breadcrumbing collection
		Collection bcs = Arrays.asList(new String[] { "Home", "Basic Tax Rates",
				"Basic Tax Rate Details" });
		request.setAttribute("breadcrumbs", bcs);

		request.setAttribute("basicTaxRate", basicTaxRate);
		request.setAttribute("basicTaxAddEditForm", baseForm);
		return mapping.findForward("success");
	}
}
