package com.softslate.commerce.businessobjects.customer;

import java.util.Collection;

import org.hibernate.envers.AuditTable;
import org.hibernate.envers.Audited;

import com.softslate.commerce.businessobjects.core.BusinessObject;

/**
 * Interface representing a customer's wish list within the system.
 * <p>
 * When the application needs to create an instance that implements
 * <code>CustomerWishList</code>,
 * {@link com.softslate.commerce.businessobjects.core.BusinessObjectFactory}
 * finds the name of the Java class to instantiate from the
 * "customerWishListImplementer" setting in the
 * <code>appComponents.properties</code> file.
 * <p>
 * The default "customerWishListImplementer" is
 * {@link com.softslate.commerce.businessobjects.customer.CustomerWishListBean}.
 * 
 * @author Jason McWilliams
 * 
 */
@Audited
@AuditTable("AudCustomerWishList")
public interface CustomerWishList extends BusinessObject {
	abstract int getCustomerWishListID();

	abstract void setCustomerWishListID(int customerWishListID);

	abstract Customer getCustomer();

	abstract void setCustomer(Customer customer);

	abstract int getCustomerID();

	abstract void setCustomerID(int customerID);

	abstract String getName();

	abstract void setName(String name);

	abstract String getDescription();

	abstract void setDescription(String description);

	abstract String getCreated();

	abstract void setCreated(String created);

	abstract String getLastUpdated();

	abstract void setLastUpdated(String lastUpdated);

	abstract Collection getCustomerWishListProducts();

	abstract void setCustomerWishListProducts(
			Collection customerWishListProducts);
	
	abstract int getItemsPerPage();

	abstract void setItemsPerPage(int itemsPerPage);

	abstract int getFirstRow();

	abstract void setFirstRow(int firstRow);

	abstract int getItemCount();

	abstract void setItemCount(int itemCount);
	
	abstract Collection getProductListCollection();

	abstract void setProductListCollection(Collection products);
}
