package com.softslate.commerce.businessobjects.order;

import java.util.Collection;
import java.util.Map;

import com.softslate.commerce.businessobjects.core.BusinessObject;

/**
 * Interface containing representations of the states and countries active in
 * the store. The states and countries are listed for customers in the Struts
 * layer as they enter in address information.
 * <p>
 * The database stores states in the <code>sscState</code> table, and
 * countries in the <code>sscCountry</code> table. The Struts layer populates
 * the two <code>Collection</code>s when the application starts. The data is
 * kept in the servlet's application scope and displayed to users filling in
 * address information.
 * <p>
 * When the application needs to create an instance that implements
 * <code>StatesAndCountries</code>,
 * {@link com.softslate.commerce.businessobjects.core.BusinessObjectFactory}
 * finds the name of the Java class to instantiate from the
 * "statesAndCountriesImplementer" setting in the
 * <code>appComponents.properties</code> file.
 * <p>
 * The default "statesAndCountriesImplementer" is
 * {@link com.softslate.commerce.businessobjects.order.StatesAndCountriesBean}.
 * 
 * @author David Tobey
 * @see com.softslate.commerce.customer.order.OrderInitializer
 */
public interface StatesAndCountries extends BusinessObject {

	/**
	 * Retrieves a <code>Collection</code> of <code>State</code> objects
	 * representing the active states in the system.
	 * 
	 * @return A <code>Collection</code> of <code>State</code> objects
	 *         representing the active states in the system.
	 */
	abstract Collection getStates();

	abstract void setStates(Collection states);

	/**
	 * Retrieves a <code>Collection</code> of <code>Country</code> objects
	 * representing the active states in the system.
	 * 
	 * @return A <code>Collection</code> of <code>Country</code> objects
	 *         representing the active states in the system.
	 */
	abstract Collection getCountries();

	abstract void setCountries(Collection countries);

	/**
	 * Retrieves a <code>Map</code>, each of whose keys is a state code, and
	 * whose values is the corresponding <code>State</code> object.
	 * 
	 * @return A <code>Map</code>, each of whose keys is a state code, and
	 * whose values is the corresponding <code>State</code> object.
	 */
	abstract Map getStateMap();

	abstract void setStateMap(Map states);

	/**
	 * Retrieves a <code>Map</code>, each of whose keys is a country code, and
	 * whose values is the corresponding <code>Country</code> object.
	 * 
	 * @return A <code>Map</code>, each of whose keys is a country code, and
	 * whose values is the corresponding <code>Country</code> object.
	 */
	abstract Map getCountryMap();

	abstract void setCountryMap(Map countries);
}
