package com.softslate.commerce.businessobjects.product;

import org.hibernate.envers.AuditTable;
import org.hibernate.envers.Audited;

import com.softslate.commerce.businessobjects.core.BusinessObject;

/**
 * Interface representing a discount range within the system.
 * <p>
 * When the application needs to create an instance that implements
 * <code>DiscountRange</code>,
 * {@link com.softslate.commerce.businessobjects.core.BusinessObjectFactory}
 * finds the name of the Java class to instantiate from the
 * "discountRangeImplementer" setting in the
 * <code>appComponents.properties</code> file.
 * <p>
 * The default "discountRangeImplementer" is
 * {@link com.softslate.commerce.businessobjects.product.DiscountRangeBean}.
 * 
 * @author David Tobey
 * 
 */
@Audited
@AuditTable("AudDiscountRange")
public interface DiscountRange extends BusinessObject {

	abstract Double getReward();

	abstract void setReward(Double reward);

	abstract String getRewardType();

	abstract void setRewardType(String rewardType);

	Double getCeiling();

	void setCeiling(Double ceiling);

	Discount getDiscount();

	void setDiscount(Discount discount);

	int getDiscountID();

	void setDiscountID(int discountID);

	int getDiscountRangeID();

	void setDiscountRangeID(int discountRangeID);

	Double getFloor();

	void setFloor(Double floor);

	boolean getIsActive();

	void setIsActive(boolean isActive);
}
