package com.softslate.commerce.businessobjects.product;

import org.hibernate.envers.AuditTable;
import org.hibernate.envers.Audited;

import com.softslate.commerce.businessobjects.core.BusinessObject;

/**
 * Interface representing a option within the system.
 * <p>
 * When the application needs to create an instance that implements
 * <code>sscOption</code>,
 * {@link com.softslate.commerce.businessobjects.core.BusinessObjectFactory}
 * finds the name of the Java class to instantiate from the "optionImplementer"
 * setting in the <code>appComponents.properties</code> file.
 * <p>
 * The default "optionImplementer" is
 * {@link com.softslate.commerce.businessobjects.product.OptionBean}.
 * 
 * @author David Tobey
 * 
 */
@Audited
@AuditTable("AudOption")
public interface Option extends BusinessObject {
	abstract int getOptionID();

	abstract void setOptionID(int optionID);

	abstract int getAttributeID();

	abstract void setAttributeID(int attributeID);

	abstract Double getOptionAltPrice();

	abstract void setOptionAltPrice(Double optionAltPrice);

	abstract String getOptionCode();

	abstract void setOptionCode(String optionCode);

	abstract String getOptionDescription();

	abstract void setOptionDescription(String optionDescription);

	abstract boolean getOptionIsActive();

	abstract void setOptionIsActive(boolean optionIsActive);

	abstract String getOptionLargeImage();

	abstract void setOptionLargeImage(String optionLargeImage);

	abstract String getOptionName();

	abstract void setOptionName(String optionName);

	abstract int getOptionOrder();

	abstract void setOptionOrder(int optionOrder);

	abstract String getOptionSmallImage();

	abstract void setOptionSmallImage(String optionSmallImage);

	abstract Double getOptionUnitCost();

	abstract void setOptionUnitCost(Double optionUnitCost);

	abstract Double getOptionUnitPrice();

	abstract void setOptionUnitPrice(Double optionUnitPrice);

	abstract Double getOptionWeight();

	abstract void setOptionWeight(Double optionWeight);

	abstract String getParentName();

	abstract void setParentName(String parentName);

	abstract Attribute getAttribute();

	abstract void setAttribute(Attribute attribute);
}
