package com.softslate.commerce.businessobjects.product;

import java.io.Serializable;

import org.hibernate.envers.AuditTable;
import org.hibernate.envers.Audited;

import com.softslate.commerce.businessobjects.core.BaseBusinessObject;

/**
 * Object representing a option within the system. <code>OptionBean</code> is
 * the default implementation of the <code>Option</code> interface for the
 * application.
 * <p>
 * The database stores options in the <code>sscOption</code> table, and this
 * interface can be used to represent a single row of that table. The Hibernate
 * configuration file <code>OptionBean.hbm.xml</code> maps that table's
 * columns to the properties in this object.
 * 
 * @author David Tobey
 * 
 */
@Audited
@AuditTable("AudOption")
public class OptionBean extends BaseBusinessObject implements Option,
		Serializable {

	private static final long serialVersionUID = -5278320563493418579L;

	private int optionID = 0;

	private int attributeID = 0;

	private Attribute attribute = null;

	private String parentName = null;

	private String optionCode = null;

	private String optionName = null;

	private String optionDescription = null;

	private boolean optionIsActive = true;

	private Double optionUnitCost = null;

	private Double optionUnitPrice = null;

	private Double optionAltPrice = null;

	private Double optionWeight = null;

	private String optionSmallImage = null;

	private String optionLargeImage = null;

	private int optionOrder = 0;

	public int getOptionID() {
		return optionID;
	}

	public void setOptionID(int optionID) {
		this.optionID = optionID;
	}

	public int getAttributeID() {
		return attributeID;
	}

	public void setAttributeID(int attributeID) {
		this.attributeID = attributeID;
	}

	public Double getOptionAltPrice() {
		return optionAltPrice;
	}

	public void setOptionAltPrice(Double optionAltPrice) {
		this.optionAltPrice = optionAltPrice;
	}

	public String getOptionCode() {
		return optionCode;
	}

	public void setOptionCode(String optionCode) {
		this.optionCode = optionCode;
	}

	public String getOptionDescription() {
		return optionDescription;
	}

	public void setOptionDescription(String optionDescription) {
		this.optionDescription = optionDescription;
	}

	public boolean getOptionIsActive() {
		return optionIsActive;
	}

	public void setOptionIsActive(boolean optionIsActive) {
		this.optionIsActive = optionIsActive;
	}

	public String getOptionLargeImage() {
		return optionLargeImage;
	}

	public void setOptionLargeImage(String optionLargeImage) {
		this.optionLargeImage = optionLargeImage;
	}

	public String getOptionName() {
		return optionName;
	}

	public void setOptionName(String optionName) {
		this.optionName = optionName;
	}

	public int getOptionOrder() {
		return optionOrder;
	}

	public void setOptionOrder(int optionOrder) {
		this.optionOrder = optionOrder;
	}

	public String getOptionSmallImage() {
		return optionSmallImage;
	}

	public void setOptionSmallImage(String optionSmallImage) {
		this.optionSmallImage = optionSmallImage;
	}

	public Double getOptionUnitCost() {
		return optionUnitCost;
	}

	public void setOptionUnitCost(Double optionUnitCost) {
		this.optionUnitCost = optionUnitCost;
	}

	public Double getOptionUnitPrice() {
		return optionUnitPrice;
	}

	public void setOptionUnitPrice(Double optionUnitPrice) {
		this.optionUnitPrice = optionUnitPrice;
	}

	public Double getOptionWeight() {
		return optionWeight;
	}

	public void setOptionWeight(Double optionWeight) {
		this.optionWeight = optionWeight;
	}

	public String getParentName() {
		return parentName;
	}

	public void setParentName(String parentName) {
		this.parentName = parentName;
	}

	public Attribute getAttribute() {
		return attribute;
	}

	public void setAttribute(Attribute attribute) {
		this.attribute = attribute;
	}
}
