package com.softslate.commerce.businessobjects.product;

import java.io.Serializable;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.envers.AuditTable;
import org.hibernate.envers.Audited;

import com.softslate.commerce.businessobjects.core.BaseBusinessObject;

/**
 * Object representing an attribute under a product in the system.
 * <code>ProductAttributeBean</code> is the default implementation of the
 * <code>ProductAttribute</code> interface for the application.
 * <p>
 * The database stores product attributes in the
 * <code>sscProductAttribute</code> table, and this interface can be used to
 * represent a single row of that table. The Hibernate configuration file
 * <code>ProductAttributeBean.hbm.xml</code> maps that table's columns to the
 * properties in this object.
 * 
 * @author David Tobey
 */
@Audited
@AuditTable("AudProductAttribute")
public class ProductAttributeBean extends BaseBusinessObject implements
		ProductAttribute, Serializable {

	private static final long serialVersionUID = -8047701591701267546L;

	static Log log = LogFactory.getLog(ProductAttributeBean.class);

	private int productAttributeID = 0;

	public int getProductAttributeID() {
		return (this.productAttributeID);
	}

	public void setProductAttributeID(int productAttributeID) {
		this.productAttributeID = productAttributeID;
	}

	private int productID = 0;

	public int getProductID() {
		return (this.productID);
	}

	public void setProductID(int productID) {
		this.productID = productID;
	}

	private int attributeID = 0;

	public int getAttributeID() {
		return (this.attributeID);
	}

	public void setAttributeID(int attributeID) {
		this.attributeID = attributeID;
	}

	private int productAttributeOrder = 0;

	public int getProductAttributeOrder() {
		return productAttributeOrder;
	}

	public void setProductAttributeOrder(int productAttributeOrder) {
		this.productAttributeOrder = productAttributeOrder;
	}

	private Product product;

	public Product getProduct() {
		return product;
	}

	public void setProduct(Product product) {
		this.product = product;
	}

	private Attribute attribute;

	public Attribute getAttribute() {
		return attribute;
	}

	public void setAttribute(Attribute attribute) {
		this.attribute = attribute;
	}
}
