package com.softslate.commerce.businessobjects.product;

import org.hibernate.envers.AuditTable;
import org.hibernate.envers.Audited;

import com.softslate.commerce.businessobjects.core.BusinessObject;

/**
 * Interface representing a related product in the system.
 * <p>
 * When the application needs to create an instance that implements
 * <code>RelatedProduct</code>,
 * {@link com.softslate.commerce.businessobjects.core.BusinessObjectFactory}
 * finds the name of the Java class to instantiate from the
 * "relatedProductImplementer" setting in the
 * <code>appComponents.properties</code> file.
 * <p>
 * The default "relatedProductImplementer" is
 * {@link com.softslate.commerce.businessobjects.product.RelatedProductBean}.
 * 
 * @author David Tobey
 * 
 */
@Audited
@AuditTable("AudRelatedProduct")
public interface RelatedProduct extends BusinessObject {

	abstract int getParentProductID();

	abstract void setParentProductID(int parentProductID);

	abstract int getProductID();

	abstract void setProductID(int productID);

	abstract int getRelatedProductID();

	abstract void setRelatedProductID(int relatedProductID);

	abstract int getRelatedProductOrder();

	abstract void setRelatedProductOrder(int relatedProductOrder);

	abstract String getRelatedType();

	abstract void setRelatedType(String relatedType);

	abstract Product getParentProduct();

	abstract void setParentProduct(Product parentProduct);

	abstract Product getProduct();

	abstract void setProduct(Product product);

}
