package com.softslate.commerce.customer.customer;

import java.util.Collection;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

import com.softslate.commerce.businessobjects.customer.CustomerProcessor;
import com.softslate.commerce.customer.core.AppUtils;
import com.softslate.commerce.customer.core.BaseAction;
import com.softslate.commerce.customer.core.BaseForm;

/**
 * Struts action class used for requests to view a customer'slist of saved carts.
 * Used for requests to "/AccountSavedCarts.do".
 * <p>
 * The <code>execute</code> method of this class invokes
 * {@link com.softslate.commerce.businessobjects.customer.CustomerProcessor#loadSavedCarts()}
 * to load the customer's list of saved carts from the database. It places a
 * <code>Collection</code> of
 * {@link com.softslate.commerce.businessobjects.order.Order} objects in the
 * request scope in an attribute named "savedCarts".
 * 
 * @author David Tobey
 * 
 */
public class AccountSavedCartsAction extends BaseAction {
	static Log log = LogFactory.getLog(AccountSavedCartsAction.class);

	public ActionForward execute(ActionMapping mapping, ActionForm form,
			HttpServletRequest request, HttpServletResponse response)
			throws Exception {
		if (log.isInfoEnabled())
			log.info("Starting action.");
		BaseForm baseForm = new BaseForm();
		baseForm.setServlet(getServlet());
		baseForm.initializeProperties(mapping, request);
		synchronized (AppUtils.getSessionLock(baseForm.getRequest().getSession())) {

			// Preserve the original request so the customer is redirected
			// back here after logging in
			request
					.setAttribute("originalRequest", request
							.getRequestURI());
			
			// If the user is not logged in, it's an error.
			if (baseForm.getUser().getCustomer() == null) {
				baseForm.getErrors().add(ActionMessages.GLOBAL_MESSAGE,
						new ActionMessage("errors.userNotLoggedIn"));
				saveErrors(baseForm.getRequest(), (ActionMessages) baseForm
						.getErrors());
				if (log.isInfoEnabled() && !baseForm.getErrors().isEmpty())
					log.info("Validation error(s): "
							+ baseForm.getErrors().toString());
				return mapping.findForward("notLoggedIn");
			}
			// Query for the customer's saved carts
			CustomerProcessor customerProcessor = (CustomerProcessor) baseForm
					.getBusinessObjectFactory().createObject(
							"customerProcessorImplementer");
			Collection savedCarts = customerProcessor.loadSavedCarts();
			// Save the carts to the request scope
			baseForm.getRequest().setAttribute("savedCartsList", savedCarts);
			// Define the starting index of the list
			String startingItem = "0";
			if (request.getParameter("startingItem") != null) {
				startingItem = request.getParameter("startingItem");
			}
			baseForm.getRequest().setAttribute("startingItem", startingItem);

			return mapping.findForward("success");
		}
	}
}
