package com.softslate.commerce.customer.customer;

import java.util.Map;

import javax.servlet.RequestDispatcher;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.beanutils.PropertyUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

import com.softslate.commerce.businessobjects.customer.CustomerProcessor;
import com.softslate.commerce.customer.core.AppUtils;
import com.softslate.commerce.customer.core.BaseAction;
import com.softslate.emailer.businessobjects.core.EmailerProcessor;

/**
 * Struts action class used for requests to register a new customer account.
 * Used for requests to "/Register.do".
 * <p>
 * The <code>execute</code> method of this class invokes
 * {@link com.softslate.commerce.businessobjects.customer.CustomerProcessor#processRegister(Map)}
 * <!-- --> to process the register request and insert the customer into the
 * system. If the customer's user name is already taken the
 * <code>ActionForward</code> named "failure" will be returned.
 * 
 * @author David Tobey
 * 
 */
public class RegisterAction extends BaseAction {
	static Log log = LogFactory.getLog(RegisterAction.class);

	public ActionForward execute(ActionMapping mapping, ActionForm form,
			HttpServletRequest request, HttpServletResponse response)
			throws Exception {
		if (log.isInfoEnabled())
			log.info("Starting action.");
		RegisterForm baseForm = (RegisterForm) form;
		synchronized (AppUtils.getSessionLock(request.getSession())) {

			// Process the registration
			CustomerProcessor customerProcessor = (CustomerProcessor) baseForm
					.getBusinessObjectFactory().createObject(
							"customerProcessorImplementer");
			Map result = customerProcessor.processRegister(PropertyUtils
					.describe(baseForm));

			// Process errors
			if (result != null && result.get("resultCode") != null
					&& !result.get("resultCode").equals("0")) {
				String resultCode = (String) result.get("resultCode");

				// Requiring email activation is a message, not an error
				if (resultCode.equals("messages.requireEmailActiviation")) {
					baseForm.getMessages().add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage(resultCode));
					saveMessages(baseForm.getRequest(), (ActionMessages) baseForm.getMessages());
					if (log.isInfoEnabled() && !baseForm.getMessages().isEmpty())
						log.info("Messages(s): " + baseForm.getMessages().toString());

				} else {
					baseForm.getErrors().add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage(resultCode));
					saveErrors(baseForm.getRequest(), (ActionMessages) baseForm.getErrors());
					if (log.isInfoEnabled() && !baseForm.getErrors().isEmpty())
						log.info("Error(s): " + baseForm.getErrors().toString());
				}
				return mapping.findForward("failure");
			}

			// Process the emailer integration
			try {
				Map parameters = PropertyUtils.describe(form);
				parameters.put("Email", baseForm.getUserName());
				EmailerProcessor processor = (EmailerProcessor) baseForm
						.getBusinessObjectFactory().createObject(
								"emailerProcessorImplementer");
				processor.processCustomerRegistration(parameters);
			} catch (Exception e) {
				log.warn("Error signing up user with Emailer: ", e);
			}

			// Forward or redirect to the original request if any
			String originalRequest = baseForm.getOriginalRequest();
			if (StringUtils.isNotBlank(originalRequest) && !originalRequest.startsWith("/administrator")) {
				originalRequest = originalRequest.replaceFirst(request.getContextPath(), "");

				// Only allow forwarding to whitelisted URLs
				String forwardAfterLoginWhitelistedURLs = baseForm.getSettings()
						.getValue("forwardAfterLoginWhitelistedURLs");
				if (StringUtils.isNotBlank(forwardAfterLoginWhitelistedURLs)) {
					String[] whitelistedURLs = forwardAfterLoginWhitelistedURLs.split(",");
					for (int i = 0; i < whitelistedURLs.length; i++) {
						if (originalRequest.equals(whitelistedURLs[i].trim())) {
							log.info("Forwarding request after login to: " + originalRequest);
							RequestDispatcher rd = request.getRequestDispatcher(originalRequest);
							rd.forward(request, response);
							return null;
						}
					}
				}

				// Otherwise, redirect
				originalRequest = baseForm.getSettings().getValue("customerSecureURL") + originalRequest;
				log.info("Redirecting request after login to: " + originalRequest);
				response.sendRedirect(originalRequest);
				return null;
			}
			return mapping.findForward("success");
		}
	}
}
