package com.softslate.commerce.customer.order;

import java.util.Collection;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.beanutils.BeanUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

import com.softslate.commerce.customer.core.ActionUtils;
import com.softslate.commerce.customer.core.AppUtils;
import com.softslate.commerce.customer.core.BaseAction;
import com.softslate.commerce.customer.core.BaseForm;

/**
 * Struts action class used for requests to clear the current cart. Used for
 * requests to "/EstimatedShipping.do".
 * <p>
 * The <code>execute</code> method of this class sets the user's delivery
 * state, zip and country so that estimated shipping costs can be calculated. It
 * then calculates them for display on the cart page.
 * 
 * @author David Tobey
 * 
 */
public class EstimatedShippingAction extends BaseAction {
	static Log log = LogFactory.getLog(EstimatedShippingAction.class);

	public ActionForward execute(ActionMapping mapping, ActionForm form,
			HttpServletRequest request, HttpServletResponse response)
			throws Exception {

		if (log.isInfoEnabled())
			log.info("Starting action.");
		BaseForm baseForm = (BaseForm) form;

		if (log.isDebugEnabled())
			log.debug("Setting delivery info for est. shipping.");

		synchronized (AppUtils.getSessionLock(request.getSession())) {

			// Set the info in the session
			BeanUtils.copyProperties(baseForm.getUser().getOrder()
					.firstDelivery(), baseForm);

			// Load new estimated shipping costs
			loadEstimatedShippingOptions(baseForm);

			return mapping.findForward("success");
		}
	}

	public Collection loadEstimatedShippingOptions(BaseForm baseForm) {
		ActionUtils actionUtils = (ActionUtils) baseForm
				.getBusinessObjectFactory().createUtilsObject(
						"actionUtilsImplementer");
		return actionUtils.loadEstimatedShippingOptions(baseForm);
	}

}
