package com.softslate.commerce.daos.email;

import java.util.Collection;
import java.util.LinkedHashSet;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.HibernateException;
import org.hibernate.Query;
import org.hibernate.Session;

import com.softslate.commerce.businessobjects.core.BusinessObjectFactory;
import com.softslate.commerce.businessobjects.email.EmailOptOut;
import com.softslate.commerce.daos.core.BaseAdminGatewayDAOHibernate;
import com.softslate.commerce.daos.core.DataAccessException;

/**
 * Generic DAO that runs miscellaneous queries related to
 * EmailOptOuts.
 */
public class EmailOptOutGatewayDAOHibernate extends BaseAdminGatewayDAOHibernate implements EmailOptOutGatewayDAO {

	static Log log = LogFactory.getLog(EmailOptOutGatewayDAOHibernate.class);

	public Map loadEmailOptOutsAndCount(Map parameters) throws Exception {
		return loadItemsAndCount(parameters);
	}

	public void editDeleteEmailOptOuts(Map parameters, BusinessObjectFactory bof) throws Exception {
		editDeleteItems(parameters, bof);
	}

	public Collection<EmailOptOut> loadAllEmailOptOuts() throws DataAccessException {
		int maxRecords = 1000;
		String maxAdminRecordsToDisplay = (String) getSettings().getValue("maxAdminRecordsToDisplay");
		if (maxAdminRecordsToDisplay != null) {
			maxRecords = Integer.parseInt(maxAdminRecordsToDisplay);
		}
		Collection<EmailOptOut> emailOptOuts = null;
		Session session = getDaoFactory().startSession();
		try {
			Query q = getNamedQuery(session, "emailOptOut.selectAll");
			q.setMaxResults(maxRecords);
			emailOptOuts = new LinkedHashSet<EmailOptOut>(q.list());
		} catch (HibernateException he) {
			if (log.isErrorEnabled())
				log.error("Hibernate error: " + he.toString());
			throw new DataAccessException(he);
		}
		return emailOptOuts;
	}

	public Integer optOutsCountByEmailAndType(String type, String emailAddress) throws Exception {
		Session session = getDaoFactory().startSession();
		try {
			Query q = getNamedQuery(session, "emailOptOut.optOutsCountByEmailAndType");
			q.setString("type", type);
			q.setString("emailAddress", emailAddress);
			return new Integer(((Long) q.uniqueResult()).intValue());
		} catch (HibernateException he) {
			if (log.isErrorEnabled())
				log.error("Hibernate error: " + he.toString());
			throw new DataAccessException(he);
		}
	}

}
