package com.softslate.commerce.daos.installer;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Collection;
import java.util.HashMap;
import java.util.LinkedHashSet;
import java.util.Map;
import java.util.Properties;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.softslate.commerce.businessobjects.administrator.Administrator;
import com.softslate.commerce.businessobjects.administrator.AdministratorBean;
import com.softslate.commerce.businessobjects.administrator.AdministratorRole;
import com.softslate.commerce.businessobjects.administrator.AdministratorRoleBean;
import com.softslate.commerce.businessobjects.administrator.Role;
import com.softslate.commerce.businessobjects.administrator.RoleBean;
import com.softslate.commerce.businessobjects.core.Settings;
import com.softslate.commerce.businessobjects.core.SettingsBean;
import com.softslate.commerce.daos.administrator.AdministratorDAO;
import com.softslate.commerce.daos.administrator.AdministratorDAOHibernate;
import com.softslate.commerce.daos.administrator.RoleDAO;
import com.softslate.commerce.daos.administrator.RoleDAOHibernate;
import com.softslate.commerce.daos.core.BaseDAO;
import com.softslate.commerce.daos.core.DAOUtils;
import com.softslate.commerce.daos.core.DAOUtilsImpl;

/**
 * 
 * @author David Tobey
 * 
 */
public class InstallerDAOBasic extends BaseDAO {

	static Log log = LogFactory.getLog(InstallerDAOBasic.class);
	public void processInitialization(String moduleList, String pathToResources, boolean insertTestData)
			throws Exception {
		if (log.isInfoEnabled())
			log.info("Processing database initialization.");
		// Set up the database connection and run queries within a
		// try/catch.
		getDaoFactory().startSession();
		doWorkToSetConnection(getDaoFactory().getSession());
		// Loop through each script, parse the queries within them,
		// adding each query to the Statement object's batch.
		String[] createScripts = moduleList.split(",");
		try {
			for (int i = 0; i < createScripts.length; i++) {
				// Process the create script
				String module = createScripts[i];
				String pathToScript = pathToResources + System.getProperty("file.separator") + module
						+ System.getProperty("file.separator") + "create_"
						+ getDaoFactory().getDatabaseType().toLowerCase() + ".sql";
				if (log.isDebugEnabled())
					log.debug("Path to script: " + pathToScript);
				// Process the create script if it exists.
				File createFile = new File(pathToScript);
				if (createFile.exists()) {
					processFile(pathToScript);
				}
				// Process the insert script if it exists.
				if (!module.equals("product")) {
					pathToScript = pathToResources + System.getProperty("file.separator") + module
							+ System.getProperty("file.separator") + "insert.sql";
					File insertFile = new File(pathToScript);
					if (insertFile.exists()) {
						if (log.isDebugEnabled())
							log.debug("Path to script: " + pathToScript);
						processFile(pathToScript);
					}
				}
			}
			// Product test data
			if (insertTestData) {
				// Process the test data script
				String pathToScript = pathToResources + System.getProperty("file.separator") + "product"
						+ System.getProperty("file.separator") + "testData_"
						+ getDaoFactory().getDatabaseType().toLowerCase() + ".sql";
				if (log.isDebugEnabled())
					log.debug("Path to script: " + pathToScript);
				processFile(pathToScript);
			}
			// Product insert script
			String pathToScript = pathToResources + System.getProperty("file.separator") + "product"
					+ System.getProperty("file.separator") + "insert.sql";
			File insertFile = new File(pathToScript);
			if (insertFile.exists()) {
				if (log.isDebugEnabled())
					log.debug("Path to script: " + pathToScript);
				processFile(pathToScript);
			}
			// Envers seed tables script
			String enableEnvers = this.getDaoFactory().getHibernateSettings()
					.getProperty("hibernate.listeners.envers.autoRegister");
			if (enableEnvers != null && enableEnvers.equals("true")) {
				String pathToSeedScript = pathToResources + System.getProperty("file.separator") + "envers"
						+ System.getProperty("file.separator") + "seed_audit_tables.sql";
				File seedFile = new File(pathToSeedScript);
				if (seedFile.exists()) {
					if (log.isDebugEnabled())
						log.debug("Path to script: " + pathToSeedScript);
					processFile(pathToSeedScript);
				}
			}
		} catch (Exception e) {
			// getConnection().rollback();
			throw e;
		}
		getConnection().commit();
		return;
	}

	public void processAdministratorInstall(Map parameters) throws Exception {
		if (log.isInfoEnabled())
			log.info("Processing administrator insert.");
		Administrator administrator = new AdministratorBean();
		administrator.setUserName((String) parameters.get("administratorUserName"));
		administrator.setDecryptedPassword((String) parameters.get("administratorPassword"));
		administrator.setIsActive(true);
		AdministratorDAO administratorDAO = new AdministratorDAOHibernate();
		Settings settings = new SettingsBean();
		settings.setMap(new HashMap());
		settings.getMap().put("administratorEncryptionType", (String) parameters.get("administratorEncryptionType"));
		settings.getMap().put("oneWayEncryptionAlgorithm", "sha256");
		Properties appSettings = new Properties();
		appSettings.setProperty("twoWayKeyFile", (String) parameters.get("twoWayKeyFile"));
		DAOUtils daoUtils = new DAOUtilsImpl();
		administratorDAO.setDaoFactory(getDaoFactory());
		administratorDAO.setSettings(settings);
		administratorDAO.setAppSettings(appSettings);
		administratorDAO.setDAOUtils(daoUtils);
		administratorDAO.setAdministrator(administrator);
		Role role = new RoleBean();
		role.setCode("superuser");
		RoleDAO roleDAO = new RoleDAOHibernate();
		roleDAO.setDaoFactory(getDaoFactory());
		roleDAO.setRole(role);
		administratorDAO.loadAdministratorByUserName();
		roleDAO.loadRoleFromCode();
		if (administratorDAO.getAdministrator() == null) {
			administratorDAO.setAdministrator(administrator);
			administratorDAO.insertAdministrator();
			AdministratorRole ar = new AdministratorRoleBean();
			ar.setAdministrator(administratorDAO.getAdministrator());
			ar.setRole(roleDAO.getRole());
			Collection administratorRoles = roleDAO.getRole().getAdministratorRoles();
			if (administratorRoles == null) {
				administratorRoles = new LinkedHashSet();
			}
			administratorRoles.add(ar);
		} else {
			administrator.setDecryptedPassword((String) parameters.get("administratorPassword"));
			administratorDAO.updateAdministrator();
		}
		getDaoFactory().commitTransaction();
	}

	/**
	 * Add all the queries in a given file to a Statement's batch. Each query
	 * must end with a semi-colon followed immediately by a newline.
	 */
	public void processFile(String pathToScript) throws Exception {
		String tablePrefix = null;
		if (getAppSettings() != null) {
			tablePrefix = getAppSettings().getProperty("databaseTablePrefix");
		}
		BufferedReader br = new BufferedReader(new FileReader(pathToScript));
		String line;
		StringBuffer contents = new StringBuffer();
		while ((line = br.readLine()) != null) {
			contents.append(line);
			if (line.endsWith(";")) {
				String statementString = contents.toString();
				statementString = statementString.substring(0, statementString.length() - 1);

				// Be smart about InnoDB vs MyISAM tables
				if (log.isDebugEnabled())
					log.debug(getDaoFactory().getHibernateSettings().getProperty("hibernate.dialect"));
				if (statementString.trim().startsWith("CREATE TABLE")
						&& getDaoFactory().getHibernateSettings() != null
						&& getDaoFactory().getHibernateSettings().getProperty("hibernate.dialect") != null
						&& getDaoFactory().getHibernateSettings().getProperty("hibernate.dialect").indexOf("InnoDB") != -1) {
					statementString = statementString + " ENGINE=InnoDB";
				}
				if (tablePrefix != null && !tablePrefix.equals("ssc")) {
					statementString = statementString.replaceAll("ssc", tablePrefix);
				}
				Statement statement1 = null;
				try {
					statement1 = getConnection().createStatement(ResultSet.TYPE_SCROLL_INSENSITIVE,
							ResultSet.CONCUR_READ_ONLY);
					statement1.execute(statementString);
				} catch (Exception e) {
					if (log.isErrorEnabled())
						log.error("Error processing statement: " + statementString + ": " + e.toString()
								+ " Current line: " + line, e);
					throw new Exception("Error processing statement: " + statementString + " Error was: "
							+ e.toString());
				} finally {
					try {
						if (statement1 != null)
							statement1.close();
					} catch (SQLException sqle) {
						log.error("Error closing statement: " + sqle.toString(), sqle);
					}
				}
				if (log.isDebugEnabled())
					log.debug(statementString);
				contents = new StringBuffer();
			} else {
				contents.append("\n");
			}
		}
		br.close();
		return;
	}
}
