package com.softslate.commerce.daos.order;

import org.apache.commons.beanutils.PropertyUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.HibernateException;
import org.hibernate.Session;

import com.softslate.commerce.businessobjects.order.OrderDelivery;
import com.softslate.commerce.daos.core.BaseDAO;
import com.softslate.commerce.daos.core.DataAccessException;


/**
 * Generic DAO to manage the <code>sscOrderDelivery</code> table of the
 * database.
 * 
 * @author David Tobey
 */
public class OrderDeliveryDAOHibernate extends BaseDAO implements
        OrderDeliveryDAO {

    static Log log = LogFactory.getLog(OrderDeliveryDAOHibernate.class);

    private OrderDelivery orderDelivery = null;

    public OrderDelivery getOrderDelivery() {
        return (this.orderDelivery);
    }

    public void setOrderDelivery(OrderDelivery orderDelivery) {
        this.orderDelivery = orderDelivery;
    }

    public void loadOrderDeliveryFromID() throws Exception {
        Session session = getDaoFactory().startSession();
        try {
            OrderDelivery record = (OrderDelivery) session.get(
                    OrderDelivery.class, new Integer(getOrderDelivery()
                            .getOrderDeliveryID()));
            PropertyUtils.copyProperties(getOrderDelivery(), record);
            setOrderDelivery(record);
        } catch (HibernateException he) {
            if (log.isErrorEnabled())
                log.error("Hibernate error: " + he.toString());
            throw new DataAccessException(he);
        }
        return;
    }

    public void insertOrderDelivery() throws DataAccessException {
        insertOrderDelivery(false);
    }

    public void insertOrderDelivery(boolean commit) throws DataAccessException {
        Session session = getDaoFactory().startSession();
        try {
            session.save(getOrderDelivery());
            if (commit) {
                getDaoFactory().commitTransaction();
            }
        } catch (HibernateException he) {
            if (log.isErrorEnabled())
                log.error("Hibernate error: " + he.toString());
            throw new DataAccessException(he);
        }
        return;
    }

    public void updateOrderDelivery() throws DataAccessException {
        updateOrderDelivery(false);
    }

    public void updateOrderDelivery(boolean commit) throws DataAccessException {
        Session session = getDaoFactory().startSession();
        try {
            session.update(getOrderDelivery());
            if (commit) {
                getDaoFactory().commitTransaction();
            }
        } catch (HibernateException he) {
            if (log.isErrorEnabled())
                log.error("Hibernate error: " + he.toString());
            throw new DataAccessException(he);
        }
        return;
    }

    public void deleteOrderDelivery() throws Exception {
        deleteOrderDelivery(false);
    }

    public void deleteOrderDelivery(boolean commit) throws Exception {
        Session session = getDaoFactory().startSession();
        try {
            setOrderDelivery((OrderDelivery) session.load(OrderDelivery.class,
                    new Integer(getOrderDelivery().getOrderDeliveryID())));
            session.delete(getOrderDelivery());
            if (commit) {
                getDaoFactory().commitTransaction();
            }
        } catch (HibernateException he) {
            if (log.isErrorEnabled())
                log.error("Hibernate error: " + he.toString());
            throw new DataAccessException(he);
        }
        return;
    }
}
