create table sscAttribute (
	attributeID number(10,0) not null, 
	class varchar2(255) DEFAULT 'com.softslate.commerce.businessobjects.product.AttributeBean', 
	attributeCode varchar2(100) not null unique, 
	attributeName varchar2(255), 
	attributeDescription clob, 
	attributeIsActive number(1,0) default 0, 
	attributeType varchar2(32) not null, 
	attributeUnitCost double precision, 
	attributeUnitPrice double precision, 
	attributeAltPrice double precision, 
	attributeWeight double precision, 
	attributeSmallImage varchar2(255), 
	attributeLargeImage varchar2(255), 
	attributeIsRequired number(1,0) default 0, 
	defaultOptionID number(10,0), 
	attributeOrder number(10,0) default 0, 
	primary key (attributeID)
);

create table sscCategory (
	categoryID number(10,0) not null, 
	class varchar2(255) DEFAULT 'com.softslate.commerce.businessobjects.product.CategoryBean', 
	parentCategory number(10,0), 
	code varchar2(100) not null unique, 
	name varchar2(255), 
	description clob, 
	keywords varchar2(255), 
	isActive number(1,0) default 0, 
	isContentPage number(1,0) default 0, 
	categoryTreeID number(10,0) default 0, 
	header clob, 
	footer clob, 
	smallImage varchar2(255), 
	mediumImage varchar2(255), 
	largeImage varchar2(255), 
	extra1 varchar2(255), 
	extra2 varchar2(255), 
	extra3 varchar2(255), 
	categoryOrder number(10,0) default 0, 
	primary key (categoryID)
);

CREATE TABLE sscManufacturer (
  manufacturerID number(10,0) not null,
  code varchar2(100) not null unique,
  name varchar2(255),
  websiteURL varchar2(255),
  description clob,
  isActive number(1,0) default 0,
  header clob,
  footer clob,
  smallImage varchar2(255),
  largeImage varchar2(255),
  isDropShipper number(1,0) default 0,
  address1 varchar2(255),
  address2 varchar2(255),
  city varchar2(100),
  state varchar2(100),
  postalCode varchar2(100),
  country varchar2(100),
  phone varchar2(100),
  email varchar2(100),
  extra1 varchar2(255),
  extra2 varchar2(255),
  extra3 varchar2(255),
  manufacturerOrder number(10,0) default 0,
  class varchar2(255) DEFAULT 'com.softslate.commerce.businessobjects.product.ManufacturerBean', 
  primary key (manufacturerID)
);

create table sscCategorySetting (
	categorySettingID number(10,0) not null, 
	class varchar2(255) DEFAULT 'com.softslate.commerce.businessobjects.product.CategorySettingBean', 
	categoryID number(10,0), 
	code varchar2(100) not null, 
	name varchar2(100), 
	description varchar2(255), 
	type varchar2(100), 
	valueType varchar2(16) not null, 
	integerValue number(10,0), 
	smallValue varchar2(64), 
	mediumValue varchar2(255), 
	textValue clob, 
	primary key (categorySettingID),
	unique (categoryID, code)
);

create table sscDiscount (
	discountID number(10,0) not null, 
	class varchar2(255) DEFAULT 'com.softslate.commerce.businessobjects.product.DiscountBean', 
	code varchar2(100) not null unique, 
	name varchar2(255), 
	description clob, 
	isActive number(1,0) default 0, 
	usersAppliesType varchar2(32), 
	usersAppliesValue varchar2(255), 
	itemsAppliesType varchar2(32), 
	itemsAppliesValue varchar2(255), 
	cartItemsType varchar2(32), 
	cartItemsValue varchar2(255), 
	rewardType varchar2(32), 
	reward double precision, 
	couponCode varchar2(64), 
	startDate varchar2(100), 
	expirationDate varchar2(100), 
	timesUsed number(10,0), 
	maxTimesUsed number(10,0), 
	isTimesPerCustomer number(1,0) default 0, 
	orderItemID number(10,0), 
	discountOrder number(10,0) default 0, 
	extra1 varchar2(255), 
	extra2 varchar2(255),
	 extra3 varchar2(255), 
	 primary key (discountID)
);

create table sscDiscountRange (
	discountRangeID number(10,0) not null, 
	class varchar2(255) DEFAULT 'com.softslate.commerce.businessobjects.product.DiscountRangeBean', 
	discountID number(10,0), 
	rewardType varchar2(32), 
	reward double precision, 
	floor double precision not null, 
	ceiling double precision not null, 
	isActive number(1,0) not null, 
	primary key (discountRangeID)
);

create table sscOption (
	optionID number(10,0) not null, 
	class varchar2(255) DEFAULT 'com.softslate.commerce.businessobjects.product.OptionBean', 
	attributeID number(10,0), 
	optionCode varchar2(100) not null, 
	optionName varchar2(255), 
	optionDescription clob, 
	optionIsActive number(1,0) default 0, 
	optionUnitCost double precision, 
	optionUnitPrice double precision, 
	optionAltPrice double precision, 
	optionWeight double precision, 
	optionSmallImage varchar2(255), 
	optionLargeImage varchar2(255), 
	optionOrder number(10,0) default 0, 
	primary key (optionID),
	unique (optionCode, attributeID)
);

create table sscProduct (
	productID number(10,0) not null, 
	class varchar2(255) DEFAULT 'com.softslate.commerce.businessobjects.product.ProductBean', 
	code varchar2(100) not null unique, 
	seoCode varchar2(255) unique, 
	name varchar2(255), 
	description clob, 
	keywords varchar2(255), 
	shortDescription varchar2(255), 
	isActive number(1,0) default 0, 
	isTaxed number(1,0) default 0, 
	unitCost double precision, 
	unitPrice double precision, 
	altPrice double precision, 
	weight double precision, 
	header clob, 
	footer clob, 
	smallImage varchar2(255), 
	mediumImage varchar2(255), 
	largeImage varchar2(255), 
	extra1 varchar2(255), 
	extra2 varchar2(255), 
	extra3 varchar2(255), 
	extra4 varchar2(255), 
	extra5 varchar2(255), 
	primaryCategoryID number(10,0), 
	productOrder number(10,0) default 0, 
	manufacturerID number(10,0), 
	created varchar2(100),
	primary key (productID)
);

create table sscProductAttribute (
	productAttributeID number(10,0) not null, 
	class varchar2(255) DEFAULT 'com.softslate.commerce.businessobjects.product.ProductAttributeBean', 
	productID number(10,0), 
	attributeID number(10,0), 
	productAttributeOrder number(10,0) default 0, 
	primary key (productAttributeID),
	unique (productID, attributeID)
);

create table sscProductCategory (
	productCategoryID number(10,0) not null, 
	class varchar2(255) DEFAULT 'com.softslate.commerce.businessobjects.product.ProductCategoryBean', 
	productID number(10,0) not null, 
	categoryID number(10,0) not null, 
	productCategoryOrder number(10,0) default 0, 
	primary key (productCategoryID),
	unique (productID, categoryID)
);

create table sscProductSetting (
	productSettingID number(10,0) not null, 
	class varchar2(255) DEFAULT 'com.softslate.commerce.businessobjects.product.ProductSettingBean', 
	productID number(10,0), 
	code varchar2(100) not null, 
	name varchar2(100), 
	description varchar2(255), 
	type varchar2(100), 
	valueType varchar2(16) not null, 
	integerValue number(10,0), 
	smallValue varchar2(64), 
	mediumValue varchar2(255), 
	textValue clob, 
	primary key (productSettingID),
	unique (productID, code)
);

create table sscRelatedProduct (
	relatedProductID number(10,0) not null, 
	class varchar2(255) DEFAULT 'com.softslate.commerce.businessobjects.product.RelatedProductBean', 
	parentProductID number(10,0), 
	productID number(10,0), 
	relatedType varchar2(32), 
	relatedProductOrder number(10,0) default 0, 
	primary key (relatedProductID),
	unique (parentProductID, productID)
);

create table sscSKU (
	skuID number(10,0) not null, 
	class varchar2(255) DEFAULT 'com.softslate.commerce.businessobjects.product.SKUBean', 
	productID number(10,0), 
	attributeID1 number(10,0), 
	optionID1 number(10,0), 
	attributeID2 number(10,0), 
	optionID2 number(10,0), 
	attributeID3 number(10,0), 
	optionID3 number(10,0), 
	attributeID4 number(10,0), 
	optionID4 number(10,0), 
	attributeID5 number(10,0), 
	optionID5 number(10,0), 
	skuNumber varchar2(128) not null unique, 
	skuName varchar2(255), 
	skuMessage varchar2(255), 
	trackInventory number(1,0) default 0, 
	inventoryLevel number(10,0) not null, 
	extra1 varchar2(255), 
	extra2 varchar2(255), 
	extra3 varchar2(255), 
	notes clob, 
	primary key (skuID),
	unique (productID, attributeID1, optionID1, attributeID2, optionID2, 
  attributeID3, optionID3, attributeID4, optionID4, attributeID5, optionID5)
);

create table sscSKUDiscount (
	skuDiscountID number(10,0) not null, 
	class varchar2(255) DEFAULT 'com.softslate.commerce.businessobjects.product.SKUDiscountBean', 
	discountID number(10,0), 
	skuID number(10,0), 
	primary key (skuDiscountID),
	unique (skuID, discountID)
);

CREATE TABLE sscProductReview (
  productReviewID number(10,0) not null,
  productID number(10,0) not null,
  status number(10,0) default 0,
  class varchar2(255) DEFAULT 'com.softslate.commerce.businessobjects.product.ProductReviewBean',
  nickname varchar2(255),
  firstName varchar2(255),
  lastName varchar2(255),
  email varchar2(255),
  age varchar2(255),
  city varchar2(255),
  state varchar2(255),
  review clob,
  rating number(10,0),
  created varchar2(255),
  imagePath varchar2(255),
  ipaddress varchar2(255),
  country varchar2(255),
  customerID number(10,0),
  primary key (productReviewID)
);

alter table sscCategory add constraint FK6DD211EA38F9586 foreign key (parentCategory) references sscCategory;
alter table sscCategorySetting add constraint FK346A7526B3F9C77 foreign key (categoryID) references sscCategory;
alter table sscOption add constraint FK8D2F749532056A73 foreign key (attributeID) references sscAttribute;
alter table sscProduct add constraint FK50C664CF5BCC8FF9 foreign key (primaryCategoryID) references sscCategory;
alter table sscProduct add constraint productManfFK foreign key (manufacturerID) references sscManufacturer;
alter table sscProductAttribute add constraint FKDDC65E8D32056A73 foreign key (attributeID) references sscAttribute;
alter table sscProductAttribute add constraint FKDDC65E8D2357AE59 foreign key (productID) references sscProduct;
alter table sscProductCategory add constraint FKD05546ED2357AE59 foreign key (productID) references sscProduct;
alter table sscProductCategory add constraint FKD05546ED6B3F9C77 foreign key (categoryID) references sscCategory;
alter table sscProductSetting add constraint FK32AC0A812357AE59 foreign key (productID) references sscProduct;
alter table sscRelatedProduct add constraint FK31589E642357AE59 foreign key (productID) references sscProduct;
alter table sscRelatedProduct add constraint FK31589E64F35AC4EF foreign key (parentProductID) references sscProduct;
alter table sscSKU add constraint FK140FD2357AE59 foreign key (productID) references sscProduct;
alter table sscSKUDiscount add constraint FK2685CD5EE324C735 foreign key (skuID) references sscSKU;
alter table sscSKUDiscount add constraint FK2685CD5E4B3E083D foreign key (discountID) references sscDiscount;
alter table sscProductReview add constraint FKPRP foreign key (productID) references sscProduct;

CREATE INDEX IDX_sscCategory_name ON sscCategory (name);
CREATE INDEX IDX_sscCategory_parentCategory ON sscCategory (parentCategory);
CREATE INDEX IDX_sscCategory_categoryOrder ON sscCategory (categoryOrder);

CREATE INDEX IDX_sscProduct_name ON sscProduct (name);
CREATE INDEX IDX_sscProduct_shortDesc ON sscProduct (shortDescription);
CREATE INDEX IDX_sscProduct_primaryCatID ON sscProduct (primaryCategoryID);
CREATE INDEX IDX_sscProduct_productOrder ON sscProduct (productOrder);

CREATE INDEX IDX_sscAttribute_name ON sscAttribute (attributeName);
CREATE INDEX IDX_sscAttribute_order ON sscAttribute (attributeOrder);

CREATE INDEX IDX_sscOption_code ON sscOption (optionCode);
CREATE INDEX IDX_sscOption_name ON sscOption (optionName);
CREATE INDEX IDX_sscOption_order ON sscOption (optionOrder);

CREATE INDEX IDX_sscDiscount_name ON sscDiscount (name);
CREATE INDEX IDX_sscDiscount_discountOrder ON sscDiscount (discountOrder);

CREATE INDEX IDX_sscDiscountRange_reward ON sscDiscountRange (reward);

CREATE INDEX IDX_sscManufacturer_name ON sscManufacturer (name);
CREATE INDEX IDX_sscManufacturer_order ON sscManufacturer (manufacturerOrder);

CREATE INDEX sscProductReview_rating ON sscProductReview (rating);
CREATE INDEX sscProductReview_nickname ON sscProductReview (nickname);

CREATE OR REPLACE TRIGGER productID_trig BEFORE INSERT ON sscProduct FOR EACH ROW BEGIN IF :new.productID IS NULL THEN SELECT hibernate_sequence.NEXTVAL into :new.productID FROM dual; END IF; END;;
CREATE OR REPLACE TRIGGER attributeID_trig BEFORE INSERT ON sscAttribute FOR EACH ROW BEGIN IF :new.attributeID IS NULL THEN SELECT hibernate_sequence.NEXTVAL into :new.attributeID FROM dual; END IF; END;;
CREATE OR REPLACE TRIGGER categoryID_trig BEFORE INSERT ON sscCategory FOR EACH ROW BEGIN IF :new.categoryID IS NULL THEN SELECT hibernate_sequence.NEXTVAL into :new.categoryID FROM dual; END IF; END;;
CREATE OR REPLACE TRIGGER optionID_trig BEFORE INSERT ON sscOption FOR EACH ROW BEGIN IF :new.optionID IS NULL THEN SELECT hibernate_sequence.NEXTVAL into :new.optionID FROM dual; END IF; END;;
CREATE OR REPLACE TRIGGER productAID_trig BEFORE INSERT ON sscProductAttribute FOR EACH ROW BEGIN IF :new.productAttributeID IS NULL THEN SELECT hibernate_sequence.NEXTVAL into :new.productAttributeID FROM dual; END IF; END;;
CREATE OR REPLACE TRIGGER productCID_trig BEFORE INSERT ON sscProductCategory FOR EACH ROW BEGIN IF :new.productCategoryID IS NULL THEN SELECT hibernate_sequence.NEXTVAL into :new.productCategoryID FROM dual; END IF; END;;
